pub trait CapabilityClientMany: CapabilityClient {
// Required method
fn many_from_dependencies(
dependencies: &Self::Dependencies,
) -> Result<Vec<BoundCapabilityClient<Self>>, Self::Error>;
}Expand description
A generated Capability client that can be connected to every explicitly bound provider in deterministic Resolved App Plan order.
Required Methods
Sourcefn many_from_dependencies(
dependencies: &Self::Dependencies,
) -> Result<Vec<BoundCapabilityClient<Self>>, Self::Error>
fn many_from_dependencies( dependencies: &Self::Dependencies, ) -> Result<Vec<BoundCapabilityClient<Self>>, Self::Error>
Connects one typed client per bound provider without performing discovery.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".